Dosenbach 2010 atlas


Notes
-----
160 regions of interest covering much of the cerebral cortex and cerebellum.
They were obtained from meta-analyses of fMRI activation studies
and assigned into 6 networks according to a modularity analysis of
resting-state data.


Content
-------
    :'rois': Coordinates of ROIs in MNI space.
    :'labels': ROIs labels.
    :'networks': Networks names.


References
----------
Dosenbach N.U., Nardos B., et al. "Prediction of individual brain maturity
using fMRI.", 2010, Science 329, 1358-1361.
